You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@directory.apache.org by el...@apache.org on 2016/02/16 18:42:34 UTC

svn commit: r1730725 - /directory/shared/trunk/ldap/model/src/main/java/org/apache/directory/api/ldap/model/message/ResultCodeEnum.java

Author: elecharny
Date: Tue Feb 16 17:42:33 2016
New Revision: 1730725

URL: http://svn.apache.org/viewvc?rev=1730725&view=rev
Log:
Changed the NO_SUCH_ERROR text to noSuchError (DIRAPI-266)

Modified:
    directory/shared/trunk/ldap/model/src/main/java/org/apache/directory/api/ldap/model/message/ResultCodeEnum.java

Modified: directory/shared/trunk/ldap/model/src/main/java/org/apache/directory/api/ldap/model/message/ResultCodeEnum.java
URL: http://svn.apache.org/viewvc/directory/shared/trunk/ldap/model/src/main/java/org/apache/directory/api/ldap/model/message/ResultCodeEnum.java?rev=1730725&r1=1730724&r2=1730725&view=diff
==============================================================================
--- directory/shared/trunk/ldap/model/src/main/java/org/apache/directory/api/ldap/model/message/ResultCodeEnum.java (original)
+++ directory/shared/trunk/ldap/model/src/main/java/org/apache/directory/api/ldap/model/message/ResultCodeEnum.java Tue Feb 16 17:42:33 2016
@@ -514,7 +514,7 @@ public enum ResultCodeEnum
     // A name error reports a problem related to the distinguished name
     // provided as an argument to an operation [X511, Section 12.5].
     //
     // For result codes of NO_SUCH_OBJECT, aliasProblem, invalidDNSyntax and
     // aliasDereferencingProblem (see Section 5.2.2.3.7), the matchedDN
     // field is set to the name of the lowest entry (object or alias) in the
     // directory that was matched. If no aliases were dereferenced while
@@ -536,7 +536,7 @@ public enum ResultCodeEnum
      * does not have permission to view or modify the entry. Applicable
      * operations: all except for Bind. Result code type: Specific (Name)
      */
-    NO_SUCH_OBJECT(32, "NO_SUCH_OBJECT"),
+    NO_SUCH_OBJECT(32, "noSuchObject"),
 
     /**
      * An alias has been dereferenced which names no object [X511, Section 12.5]
@@ -514,7 +514,7 @@ public enum ResultCodeEnum
     // provided as an argument to an operation [X511, Section 12.5].
     //
-    // For result codes of NO_SUCH_OBJECT, aliasProblem, invalidDNSyntax and
+    // For result codes of noSuchObject, aliasProblem, invalidDNSyntax and
     // aliasDereferencingProblem (see Section 5.2.2.3.7), the matchedDN
     // field is set to the name of the lowest entry (object or alias) in the